==> zio-aws-codeartifact_3-5.17.178.1-sources.jar: zio/aws/codeartifact/model/RepositoryDescription.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.{
  AccountId,
  DomainName,
  RepositoryName,
  Arn,
  Description
}
import scala.jdk.CollectionConverters.*
final case class RepositoryDescription(
    name: Optional[RepositoryName] = Optional.Absent,
    administratorAccount: Optional[AccountId] = Optional.Absent,
    domainName: Optional[DomainName] = Optional.Absent,
    domainOwner: Optional[AccountId] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    upstreams: Optional[
      Iterable[zio.aws.codeartifact.model.UpstreamRepositoryInfo]
    ] = Optional.Absent,
    externalConnections: Optional[
      Iterable[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.RepositoryDescription = {
    import RepositoryDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
      .builder()
      .optionallyWith(
        name.map(value => RepositoryName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        administratorAccount.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.administratorAccount)
      .optionallyWith(
        domainName.map(value => DomainName.unwrap(value): java.lang.String)
      )(_.domainName)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        upstreams.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.upstreams)
      .optionallyWith(
        externalConnections.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.externalConnections)
      .build()
  }
  def asReadOnly: zio.aws.codeartifact.model.RepositoryDescription.ReadOnly =
    zio.aws.codeartifact.model.RepositoryDescription.wrap(buildAwsValue())
}
object RepositoryDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codeartifact.model.RepositoryDescription =
      zio.aws.codeartifact.model.RepositoryDescription(
        name.map(value => value),
        administratorAccount.map(value => value),
        domainName.map(value => value),
        domainOwner.map(value => value),
        arn.map(value => value),
        description.map(value => value),
        upstreams.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        externalConnections.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def name: Optional[RepositoryName]
    def administratorAccount: Optional[AccountId]
    def domainName: Optional[DomainName]
    def domainOwner: Optional[AccountId]
    def arn: Optional[Arn]
    def description: Optional[Description]
    def upstreams: Optional[
      List[zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly]
    ]
    def externalConnections: Optional[
      List[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly]
    ]
    def getName: ZIO[Any, AwsError, RepositoryName] =
      AwsError.unwrapOptionField("name", name)
    def getAdministratorAccount: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("administratorAccount", administratorAccount)
    def getDomainName: ZIO[Any, AwsError, DomainName] =
      AwsError.unwrapOptionField("domainName", domainName)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getUpstreams: ZIO[Any, AwsError, List[
      zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("upstreams", upstreams)
    def getExternalConnections: ZIO[Any, AwsError, List[
      zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("externalConnections", externalConnections)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ) extends zio.aws.codeartifact.model.RepositoryDescription.ReadOnly {
    override val name: Optional[RepositoryName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.codeartifact.model.primitives.RepositoryName(value))
    override val administratorAccount: Optional[AccountId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.administratorAccount())
        .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val domainName: Optional[DomainName] = zio.aws.core.internal
      .optionalFromNullable(impl.domainName())
      .map(value => zio.aws.codeartifact.model.primitives.DomainName(value))
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.codeartifact.model.primitives.Arn(value))
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.codeartifact.model.primitives.Description(value))
    override val upstreams: Optional[
      List[zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.upstreams())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codeartifact.model.UpstreamRepositoryInfo.wrap(item)
        }.toList
      )
    override val externalConnections: Optional[
      List[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.externalConnections())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ): zio.aws.codeartifact.model.RepositoryDescription.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codeartifact_3-6.20.78.3-sources.jar: zio/aws/codeartifact/model/RepositoryDescription.scala <==
package zio.aws.codeartifact.model
import zio.aws.codeartifact.model.primitives.{
  AccountId,
  Timestamp,
  DomainName,
  RepositoryName,
  Arn,
  Description
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class RepositoryDescription(
    name: Optional[RepositoryName] = Optional.Absent,
    administratorAccount: Optional[AccountId] = Optional.Absent,
    domainName: Optional[DomainName] = Optional.Absent,
    domainOwner: Optional[AccountId] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent,
    description: Optional[Description] = Optional.Absent,
    upstreams: Optional[
      Iterable[zio.aws.codeartifact.model.UpstreamRepositoryInfo]
    ] = Optional.Absent,
    externalConnections: Optional[
      Iterable[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo]
    ] = Optional.Absent,
    createdTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.RepositoryDescription = {
    import RepositoryDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
      .builder()
      .optionallyWith(
        name.map(value => RepositoryName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        administratorAccount.map(value =>
          AccountId.unwrap(value): java.lang.String
        )
      )(_.administratorAccount)
      .optionallyWith(
        domainName.map(value => DomainName.unwrap(value): java.lang.String)
      )(_.domainName)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        upstreams.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.upstreams)
      .optionallyWith(
        externalConnections.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.externalConnections)
      .optionallyWith(
        createdTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.createdTime)
      .build()
  }
  def asReadOnly: zio.aws.codeartifact.model.RepositoryDescription.ReadOnly =
    zio.aws.codeartifact.model.RepositoryDescription.wrap(buildAwsValue())
}
object RepositoryDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codeartifact.model.RepositoryDescription =
      zio.aws.codeartifact.model.RepositoryDescription(
        name.map(value => value),
        administratorAccount.map(value => value),
        domainName.map(value => value),
        domainOwner.map(value => value),
        arn.map(value => value),
        description.map(value => value),
        upstreams.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        externalConnections.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        createdTime.map(value => value)
      )
    def name: Optional[RepositoryName]
    def administratorAccount: Optional[AccountId]
    def domainName: Optional[DomainName]
    def domainOwner: Optional[AccountId]
    def arn: Optional[Arn]
    def description: Optional[Description]
    def upstreams: Optional[
      List[zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly]
    ]
    def externalConnections: Optional[
      List[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly]
    ]
    def createdTime: Optional[Timestamp]
    def getName: ZIO[Any, AwsError, RepositoryName] =
      AwsError.unwrapOptionField("name", name)
    def getAdministratorAccount: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("administratorAccount", administratorAccount)
    def getDomainName: ZIO[Any, AwsError, DomainName] =
      AwsError.unwrapOptionField("domainName", domainName)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getUpstreams: ZIO[Any, AwsError, List[
      zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("upstreams", upstreams)
    def getExternalConnections: ZIO[Any, AwsError, List[
      zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly
    ]] = AwsError.unwrapOptionField("externalConnections", externalConnections)
    def getCreatedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdTime", createdTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ) extends zio.aws.codeartifact.model.RepositoryDescription.ReadOnly {
    override val name: Optional[RepositoryName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.codeartifact.model.primitives.RepositoryName(value))
    override val administratorAccount: Optional[AccountId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.administratorAccount())
        .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val domainName: Optional[DomainName] = zio.aws.core.internal
      .optionalFromNullable(impl.domainName())
      .map(value => zio.aws.codeartifact.model.primitives.DomainName(value))
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.codeartifact.model.primitives.Arn(value))
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.codeartifact.model.primitives.Description(value))
    override val upstreams: Optional[
      List[zio.aws.codeartifact.model.UpstreamRepositoryInfo.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.upstreams())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codeartifact.model.UpstreamRepositoryInfo.wrap(item)
        }.toList
      )
    override val externalConnections: Optional[
      List[zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.externalConnections())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codeartifact.model.RepositoryExternalConnectionInfo.wrap(item)
        }.toList
      )
    override val createdTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdTime())
      .map(value => zio.aws.codeartifact.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.RepositoryDescription
  ): zio.aws.codeartifact.model.RepositoryDescription.ReadOnly = new Wrapper(
    impl
  )
}
